#!/bin/sh
#
# requires: ...topnm, pnmscale, pnmcomp, ppmntsc, ppmtoy4m, mpeg2enc
#

SELF=`basename $0 .sh`
BACKGROUND=/var/cache/vdr-plugin-mp3/images/mp3_background.pnm
[ -e "$BACKGROUND" ] || ppmmake rgb:0/0/0 704 576 >"$BACKGROUND"

IMG=$1
MPG=$2

DW=704 # destination frame width
DH=576 # destination frame height

TW=632 # target image width (taking into account visible screen area)
TH=512 # target image height 

IW=0   # image width
IH=0   # image height

if [ -s "${MPG}" ]
then
  logger "${SELF}: $MPG already exists"
else
  logger "${SELF}: $IMG -> $MPG"
  DIR=`dirname "${MPG}"`
  if [ ! -d "${DIR}" ]
  then
    mkdir -p "${DIR}"
  fi
  #
  # get the file type and set the according converter to PNM
  #
  FILE_DETECT=$(file -i -L -b "${IMG}" 2>/dev/null)
  FILE_TYPE=$(echo "$FILE_DETECT"|cut -f1 -d";"|cut -f1 -d"/")
  FILE_SUB_TYPE=$(echo "$FILE_DETECT"|cut -f1 -d";"|cut -f2 -d"/")

  case "$FILE_SUB_TYPE" in
    jpg | jpeg)
    TO_PNM=jpegtopnm
    ;;
    tiff)
    TO_PNM=tifftopnm
    ;;
    bmp | x-bmp)
    TO_PNM=bmptoppm
    ;;
    png | x-png)
    TO_PNM=pngtopnm
    ;;
    Netpbm | pnm | x-portable-pixmap)
    TO_PNM=cat
    ;;
    gif)
    TO_PNM=giftopnm
    ;;
    *)
    echo "file '$FILE_TYPE/$FILE_SUB_TYPE' is not of supported type , EXIT 1" 1>&2
    exit 1
    ;;
  esac
  #
  # extract the image size
  #
  $TO_PNM "${IMG}" > /tmp/image.pnm 2> /dev/null
  IMG_SIZE=`pnmfile /tmp/image.pnm | awk '{ printf "%dx%d", $4, $6 }'`
  IW=`echo $IMG_SIZE | cut -d'x' -f1`
  IH=`echo $IMG_SIZE | cut -d'x' -f2`
  #
  # compute the scaling factor and the target image size
  #
  S=`echo $IW ${TW} $IH ${TH} | awk '{ sw = $2 / $1; sh = $4 / $3; s = (sw < sh) ? sw : sh; } END { if (s < 1) print s; else print 1.0 }'`
  IW=`echo $IW $S | awk '{ printf "%.0f", $1 * $2 }'`
  IH=`echo $IH $S | awk '{ printf "%.0f", $1 * $2 }'`
  #echo "${SELF}: scaling by $S to ${IW}x${IH}" 1>&2
  #
  # now run the conversion
  #
  pnmscale -xsize=${IW} -ysize=${IH} /tmp/image.pnm | \
    pnmcomp -align=center -valign=middle - $BACKGROUND | \
    ppmntsc --pal | \
    ppmtoy4m -v 0 -n 1 -r -F 25:1 | \
    mpeg2enc -f 7 -T 90 -F 3 -np -a 2 -v 0 -o "${MPG}"
  #
  # cleanup
  #
  rm /tmp/image.pnm
fi
